<!--
SPDX-FileCopyrightText: 2023 imotai <jackwang@octogen.dev>
SPDX-FileContributor: imotai

SPDX-License-Identifier: Elastic-2.0
-->

the protobuf module of octogen

build the proto module
```
pip install -r requirements.txt
```
generate the python stubs and  replace the module path
```
make
```
